# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.25.0-v202506042330-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class IdentityMappingV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'mapped_identity_data_id': 'str',
        'provider_datasource_class': 'str',
        'provider_datasource_id': 'str'
    }

    attribute_map = {
        'mapped_identity_data_id': 'mappedIdentityDataId',
        'provider_datasource_class': 'providerDatasourceClass',
        'provider_datasource_id': 'providerDatasourceId'
    }

    def __init__(self, mapped_identity_data_id=None, provider_datasource_class=None, provider_datasource_id=None):
        """
        IdentityMappingV1 - a model defined in Swagger
        """

        self._mapped_identity_data_id = None
        self._provider_datasource_class = None
        self._provider_datasource_id = None

        if mapped_identity_data_id is not None:
          self.mapped_identity_data_id = mapped_identity_data_id
        if provider_datasource_class is not None:
          self.provider_datasource_class = provider_datasource_class
        if provider_datasource_id is not None:
          self.provider_datasource_id = provider_datasource_id

    @property
    def mapped_identity_data_id(self):
        """
        Gets the mapped_identity_data_id of this IdentityMappingV1.
        A unique identifier for the identity within its datasource.

        :return: The mapped_identity_data_id of this IdentityMappingV1.
        :rtype: str
        """
        return self._mapped_identity_data_id

    @mapped_identity_data_id.setter
    def mapped_identity_data_id(self, mapped_identity_data_id):
        """
        Sets the mapped_identity_data_id of this IdentityMappingV1.
        A unique identifier for the identity within its datasource.

        :param mapped_identity_data_id: The mapped_identity_data_id of this IdentityMappingV1.
        :type: str
        """

        self._mapped_identity_data_id = mapped_identity_data_id

    @property
    def provider_datasource_class(self):
        """
        Gets the provider_datasource_class of this IdentityMappingV1.
        Along with the Provider Datasource ID, the Provider Datasource Class uniquely identifies the datasource who provides the mapped user group. For example, a datasource may be a particular instance of an AD.

        :return: The provider_datasource_class of this IdentityMappingV1.
        :rtype: str
        """
        return self._provider_datasource_class

    @provider_datasource_class.setter
    def provider_datasource_class(self, provider_datasource_class):
        """
        Sets the provider_datasource_class of this IdentityMappingV1.
        Along with the Provider Datasource ID, the Provider Datasource Class uniquely identifies the datasource who provides the mapped user group. For example, a datasource may be a particular instance of an AD.

        :param provider_datasource_class: The provider_datasource_class of this IdentityMappingV1.
        :type: str
        """

        self._provider_datasource_class = provider_datasource_class

    @property
    def provider_datasource_id(self):
        """
        Gets the provider_datasource_id of this IdentityMappingV1.
        Along with the Provider Datasource Class, the Provider Datasource ID uniquely identifies the datasource who provides the mapped user group. For example, a datasource may be a particular instance of an AD.

        :return: The provider_datasource_id of this IdentityMappingV1.
        :rtype: str
        """
        return self._provider_datasource_id

    @provider_datasource_id.setter
    def provider_datasource_id(self, provider_datasource_id):
        """
        Sets the provider_datasource_id of this IdentityMappingV1.
        Along with the Provider Datasource Class, the Provider Datasource ID uniquely identifies the datasource who provides the mapped user group. For example, a datasource may be a particular instance of an AD.

        :param provider_datasource_id: The provider_datasource_id of this IdentityMappingV1.
        :type: str
        """

        self._provider_datasource_id = provider_datasource_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, IdentityMappingV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.25.0-v202506042330-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class DatasourceStatusV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'datasource_class': 'str',
        'datasource_guid': 'str',
        'datasource_id': 'str',
        'datasource_name': 'str',
        'enabled': 'bool',
        'seeq_internal': 'bool',
        'statistics': 'DatasourceStatisticsV1',
        'stored_in_seeq': 'bool'
    }

    attribute_map = {
        'datasource_class': 'datasourceClass',
        'datasource_guid': 'datasourceGuid',
        'datasource_id': 'datasourceId',
        'datasource_name': 'datasourceName',
        'enabled': 'enabled',
        'seeq_internal': 'seeqInternal',
        'statistics': 'statistics',
        'stored_in_seeq': 'storedInSeeq'
    }

    def __init__(self, datasource_class=None, datasource_guid=None, datasource_id=None, datasource_name=None, enabled=False, seeq_internal=False, statistics=None, stored_in_seeq=False):
        """
        DatasourceStatusV1 - a model defined in Swagger
        """

        self._datasource_class = None
        self._datasource_guid = None
        self._datasource_id = None
        self._datasource_name = None
        self._enabled = None
        self._seeq_internal = None
        self._statistics = None
        self._stored_in_seeq = None

        if datasource_class is not None:
          self.datasource_class = datasource_class
        if datasource_guid is not None:
          self.datasource_guid = datasource_guid
        if datasource_id is not None:
          self.datasource_id = datasource_id
        if datasource_name is not None:
          self.datasource_name = datasource_name
        if enabled is not None:
          self.enabled = enabled
        if seeq_internal is not None:
          self.seeq_internal = seeq_internal
        if statistics is not None:
          self.statistics = statistics
        if stored_in_seeq is not None:
          self.stored_in_seeq = stored_in_seeq

    @property
    def datasource_class(self):
        """
        Gets the datasource_class of this DatasourceStatusV1.
        The class of the datasource

        :return: The datasource_class of this DatasourceStatusV1.
        :rtype: str
        """
        return self._datasource_class

    @datasource_class.setter
    def datasource_class(self, datasource_class):
        """
        Sets the datasource_class of this DatasourceStatusV1.
        The class of the datasource

        :param datasource_class: The datasource_class of this DatasourceStatusV1.
        :type: str
        """

        self._datasource_class = datasource_class

    @property
    def datasource_guid(self):
        """
        Gets the datasource_guid of this DatasourceStatusV1.
        The Seeq ID of the datasource

        :return: The datasource_guid of this DatasourceStatusV1.
        :rtype: str
        """
        return self._datasource_guid

    @datasource_guid.setter
    def datasource_guid(self, datasource_guid):
        """
        Sets the datasource_guid of this DatasourceStatusV1.
        The Seeq ID of the datasource

        :param datasource_guid: The datasource_guid of this DatasourceStatusV1.
        :type: str
        """

        self._datasource_guid = datasource_guid

    @property
    def datasource_id(self):
        """
        Gets the datasource_id of this DatasourceStatusV1.
        The ID of the datasource

        :return: The datasource_id of this DatasourceStatusV1.
        :rtype: str
        """
        return self._datasource_id

    @datasource_id.setter
    def datasource_id(self, datasource_id):
        """
        Sets the datasource_id of this DatasourceStatusV1.
        The ID of the datasource

        :param datasource_id: The datasource_id of this DatasourceStatusV1.
        :type: str
        """

        self._datasource_id = datasource_id

    @property
    def datasource_name(self):
        """
        Gets the datasource_name of this DatasourceStatusV1.
        The name of the datasource

        :return: The datasource_name of this DatasourceStatusV1.
        :rtype: str
        """
        return self._datasource_name

    @datasource_name.setter
    def datasource_name(self, datasource_name):
        """
        Sets the datasource_name of this DatasourceStatusV1.
        The name of the datasource

        :param datasource_name: The datasource_name of this DatasourceStatusV1.
        :type: str
        """

        self._datasource_name = datasource_name

    @property
    def enabled(self):
        """
        Gets the enabled of this DatasourceStatusV1.
        Whether the datasource is enabled

        :return: The enabled of this DatasourceStatusV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this DatasourceStatusV1.
        Whether the datasource is enabled

        :param enabled: The enabled of this DatasourceStatusV1.
        :type: bool
        """

        self._enabled = enabled

    @property
    def seeq_internal(self):
        """
        Gets the seeq_internal of this DatasourceStatusV1.
        Whether this datasource is internal to Seeq (System Datasource) or not.

        :return: The seeq_internal of this DatasourceStatusV1.
        :rtype: bool
        """
        return self._seeq_internal

    @seeq_internal.setter
    def seeq_internal(self, seeq_internal):
        """
        Sets the seeq_internal of this DatasourceStatusV1.
        Whether this datasource is internal to Seeq (System Datasource) or not.

        :param seeq_internal: The seeq_internal of this DatasourceStatusV1.
        :type: bool
        """

        self._seeq_internal = seeq_internal

    @property
    def statistics(self):
        """
        Gets the statistics of this DatasourceStatusV1.

        :return: The statistics of this DatasourceStatusV1.
        :rtype: DatasourceStatisticsV1
        """
        return self._statistics

    @statistics.setter
    def statistics(self, statistics):
        """
        Sets the statistics of this DatasourceStatusV1.

        :param statistics: The statistics of this DatasourceStatusV1.
        :type: DatasourceStatisticsV1
        """

        self._statistics = statistics

    @property
    def stored_in_seeq(self):
        """
        Gets the stored_in_seeq of this DatasourceStatusV1.
        Whether the actual data is stored in Seeq or not.

        :return: The stored_in_seeq of this DatasourceStatusV1.
        :rtype: bool
        """
        return self._stored_in_seeq

    @stored_in_seeq.setter
    def stored_in_seeq(self, stored_in_seeq):
        """
        Sets the stored_in_seeq of this DatasourceStatusV1.
        Whether the actual data is stored in Seeq or not.

        :param stored_in_seeq: The stored_in_seeq of this DatasourceStatusV1.
        :type: bool
        """

        self._stored_in_seeq = stored_in_seeq

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DatasourceStatusV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.25.0-v202506042330-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class LabelCategoryOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'is_autocomplete': 'bool',
        'name': 'str',
        'parent_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'is_autocomplete': 'isAutocomplete',
        'name': 'name',
        'parent_id': 'parentId'
    }

    def __init__(self, id=None, is_autocomplete=None, name=None, parent_id=None):
        """
        LabelCategoryOutputV1 - a model defined in Swagger
        """

        self._id = None
        self._is_autocomplete = None
        self._name = None
        self._parent_id = None

        if id is not None:
          self.id = id
        if is_autocomplete is not None:
          self.is_autocomplete = is_autocomplete
        if name is not None:
          self.name = name
        if parent_id is not None:
          self.parent_id = parent_id

    @property
    def id(self):
        """
        Gets the id of this LabelCategoryOutputV1.
        ID of the label category

        :return: The id of this LabelCategoryOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LabelCategoryOutputV1.
        ID of the label category

        :param id: The id of this LabelCategoryOutputV1.
        :type: str
        """

        self._id = id

    @property
    def is_autocomplete(self):
        """
        Gets the is_autocomplete of this LabelCategoryOutputV1.

        :return: The is_autocomplete of this LabelCategoryOutputV1.
        :rtype: bool
        """
        return self._is_autocomplete

    @is_autocomplete.setter
    def is_autocomplete(self, is_autocomplete):
        """
        Sets the is_autocomplete of this LabelCategoryOutputV1.

        :param is_autocomplete: The is_autocomplete of this LabelCategoryOutputV1.
        :type: bool
        """

        self._is_autocomplete = is_autocomplete

    @property
    def name(self):
        """
        Gets the name of this LabelCategoryOutputV1.
        Name of the label category

        :return: The name of this LabelCategoryOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LabelCategoryOutputV1.
        Name of the label category

        :param name: The name of this LabelCategoryOutputV1.
        :type: str
        """

        self._name = name

    @property
    def parent_id(self):
        """
        Gets the parent_id of this LabelCategoryOutputV1.
        If present, the ID of the parent category

        :return: The parent_id of this LabelCategoryOutputV1.
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """
        Sets the parent_id of this LabelCategoryOutputV1.
        If present, the ID of the parent category

        :param parent_id: The parent_id of this LabelCategoryOutputV1.
        :type: str
        """

        self._parent_id = parent_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, LabelCategoryOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.25.0-v202506042330-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import sys
import os
import re

from deprecated import deprecated
# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient
from ..models import *

class ProjectsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def add_schedule_notebook_result(self, **kwargs):
        """
        Report the results of a scheduled notebook execution. For internal use only.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_schedule_notebook_result(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ScheduledNotebookResultInputV1 body: The Notebook run result (required)
        :param str id: ID of the Scheduled Notebook (required)
        :return: ScheduledNotebookOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ScheduledNotebookOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.add_schedule_notebook_result_with_http_info(**kwargs)
        else:
            (data) = self.add_schedule_notebook_result_with_http_info(**kwargs)
            return data

    def add_schedule_notebook_result_with_http_info(self, **kwargs):
        """
        Report the results of a scheduled notebook execution. For internal use only.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_schedule_notebook_result_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ScheduledNotebookResultInputV1 body: The Notebook run result (required)
        :param str id: ID of the Scheduled Notebook (required)
        :return: ScheduledNotebookOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ScheduledNotebookOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_schedule_notebook_result" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `add_schedule_notebook_result`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `add_schedule_notebook_result`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/projects/scheduledNotebooks/{id}/result', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ScheduledNotebookOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def archive_project(self, **kwargs):
        """
        Archive a project
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_project(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the project to archive (required)
        :return: ArchiveOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ArchiveOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.archive_project_with_http_info(**kwargs)
        else:
            (data) = self.archive_project_with_http_info(**kwargs)
            return data

    def archive_project_with_http_info(self, **kwargs):
        """
        Archive a project
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.archive_project_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the project to archive (required)
        :return: ArchiveOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ArchiveOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `archive_project`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/projects/{id}', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ArchiveOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_project(self, **kwargs):
        """
        Create a project
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_project(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ProjectInputV1 body: Project information (required)
        :return: ProjectOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ProjectOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_project_with_http_info(**kwargs)
        else:
            (data) = self.create_project_with_http_info(**kwargs)
            return data

    def create_project_with_http_info(self, **kwargs):
        """
        Create a project
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_project_with_http_info(body=body_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ProjectInputV1 body: Project information (required)
        :return: ProjectOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ProjectOutputV1
        """

        all_params = ['body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_project`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/projects', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ProjectOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_project(self, **kwargs):
        """
        Get a project
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_project(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the project to retrieve (required)
        :return: ProjectOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ProjectOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_project_with_http_info(**kwargs)
        else:
            (data) = self.get_project_with_http_info(**kwargs)
            return data

    def get_project_with_http_info(self, **kwargs):
        """
        Get a project
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_project_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the project to retrieve (required)
        :return: ProjectOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ProjectOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_project`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/projects/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ProjectOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_projects(self, **kwargs):
        """
        List projects
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_projects(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :return: GetProjectsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetProjectsOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_projects_with_http_info(**kwargs)
        else:
            (data) = self.get_projects_with_http_info(**kwargs)
            return data

    def get_projects_with_http_info(self, **kwargs):
        """
        List projects
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_projects_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :return: GetProjectsOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetProjectsOutputV1
        """

        all_params = ['offset', 'limit']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_projects" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/projects', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'GetProjectsOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_scheduled_notebook(self, **kwargs):
        """
        Get the details of a scheduled notebook
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_scheduled_notebook(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: (required)
        :return: ScheduledNotebookOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ScheduledNotebookOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_scheduled_notebook_with_http_info(**kwargs)
        else:
            (data) = self.get_scheduled_notebook_with_http_info(**kwargs)
            return data

    def get_scheduled_notebook_with_http_info(self, **kwargs):
        """
        Get the details of a scheduled notebook
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_scheduled_notebook_with_http_info(id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: (required)
        :return: ScheduledNotebookOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ScheduledNotebookOutputV1
        """

        all_params = ['id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_scheduled_notebook" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_scheduled_notebook`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/projects/scheduledNotebooks/{id}', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ScheduledNotebookOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_scheduled_notebooks(self, **kwargs):
        """
        List all scheduled notebooks the current user has scheduled
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_scheduled_notebooks(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :param bool is_enabled: Set to true to filter only the notebooks which are enabled
        :return: ScheduledNotebookListOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ScheduledNotebookListOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_scheduled_notebooks_with_http_info(**kwargs)
        else:
            (data) = self.get_scheduled_notebooks_with_http_info(**kwargs)
            return data

    def get_scheduled_notebooks_with_http_info(self, **kwargs):
        """
        List all scheduled notebooks the current user has scheduled
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_scheduled_notebooks_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int offset: The pagination offset, the index of the first collection item that will be returned in this page of results
        :param int limit: The pagination limit, the total number of collection items that will be returned in this page of results
        :param bool is_enabled: Set to true to filter only the notebooks which are enabled
        :return: ScheduledNotebookListOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ScheduledNotebookListOutputV1
        """

        all_params = ['offset', 'limit', 'is_enabled']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_scheduled_notebooks" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'is_enabled' in params:
            query_params.append(('isEnabled', params['is_enabled']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/projects/scheduledNotebooks', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ScheduledNotebookListOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def put_project(self, **kwargs):
        """
        Update a project
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_project(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ProjectInputV1 body: (required)
        :param str id: The Seeq ID for the project (required)
        :return: ProjectOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ProjectOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.put_project_with_http_info(**kwargs)
        else:
            (data) = self.put_project_with_http_info(**kwargs)
            return data

    def put_project_with_http_info(self, **kwargs):
        """
        Update a project
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_project_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ProjectInputV1 body: (required)
        :param str id: The Seeq ID for the project (required)
        :return: ProjectOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ProjectOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_project`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `put_project`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/projects/{id}', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ProjectOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def schedule_notebook(self, **kwargs):
        """
        Schedule a Notebook within a Project to run on a set interval
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.schedule_notebook(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ScheduledNotebookInputV1 body: The Notebook schedule information (required)
        :param str id: ID of the Project containing the Notebook to schedule (required)
        :return: ScheduledNotebookOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ScheduledNotebookOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.schedule_notebook_with_http_info(**kwargs)
        else:
            (data) = self.schedule_notebook_with_http_info(**kwargs)
            return data

    def schedule_notebook_with_http_info(self, **kwargs):
        """
        Schedule a Notebook within a Project to run on a set interval
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.schedule_notebook_with_http_info(body=body_value, id=id_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ScheduledNotebookInputV1 body: The Notebook schedule information (required)
        :param str id: ID of the Project containing the Notebook to schedule (required)
        :return: ScheduledNotebookOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ScheduledNotebookOutputV1
        """

        all_params = ['body', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method schedule_notebook" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `schedule_notebook`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `schedule_notebook`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/projects/{id}/scheduleNotebook', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ScheduledNotebookOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def unschedule_notebook(self, **kwargs):
        """
        Archive Scheduled Notebook(s) within a Project so that it will no longer run
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.unschedule_notebook(id=id_value, file_path=file_path_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the Project containing the Notebook to unschedule (required)
        :param str file_path: The path to the Notebook file. Using '*' will unschedule all Notebooks for this Project, regardless of their label (required)
        :param str label: The label for the Notebook schedule. Using '*' will unschedule all labels for this filePath
        :return: ScheduledNotebookListOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ScheduledNotebookListOutputV1
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.unschedule_notebook_with_http_info(**kwargs)
        else:
            (data) = self.unschedule_notebook_with_http_info(**kwargs)
            return data

    def unschedule_notebook_with_http_info(self, **kwargs):
        """
        Archive Scheduled Notebook(s) within a Project so that it will no longer run
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.unschedule_notebook_with_http_info(id=id_value, file_path=file_path_value, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: ID of the Project containing the Notebook to unschedule (required)
        :param str file_path: The path to the Notebook file. Using '*' will unschedule all Notebooks for this Project, regardless of their label (required)
        :param str label: The label for the Notebook schedule. Using '*' will unschedule all labels for this filePath
        :return: ScheduledNotebookListOutputV1
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ScheduledNotebookListOutputV1
        """

        all_params = ['id', 'file_path', 'label']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')
        all_params.append('_response_type')
        all_params.append('_custom_headers')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method unschedule_notebook" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `unschedule_notebook`")
        # verify the required parameter 'file_path' is set
        if ('file_path' not in params) or (params['file_path'] is None):
            raise ValueError("Missing the required parameter `file_path` when calling `unschedule_notebook`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []
        if 'file_path' in params:
            query_params.append(('filePath', params['file_path']))
        if 'label' in params:
            query_params.append(('label', params['label']))

        header_params = {}

        for key, value in params.get('_custom_headers', {}).items():
            header_params[key] = value


        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/vnd.seeq.v1+json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/vnd.seeq.v1+json', ])

        # Authentication setting
        auth_settings = ['api_key']

        return self.api_client.call_api('/projects/{id}/scheduleNotebook', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=params.get('_response_type', 'ScheduledNotebookListOutputV1'),
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.25.0-v202506042330-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class UserGroupOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'capabilities': 'list[CapabilityInheritanceOutputV1]',
        'capability_grants': 'list[CapabilityInheritanceOutputV1]',
        'created_at': 'str',
        'data_id': 'str',
        'datasource_class': 'str',
        'datasource_id': 'str',
        'datasource_name': 'str',
        'description': 'str',
        'effective_permissions': 'PermissionsV1',
        'id': 'str',
        'is_archived': 'bool',
        'is_enabled': 'bool',
        'is_redacted': 'bool',
        'is_remote_group_editable': 'bool',
        'is_used_in_access_control_entries': 'bool',
        'members': 'list[IdentityPreviewV1]',
        'name': 'str',
        'status_message': 'str',
        'sync_token': 'str',
        'translation_key': 'str',
        'type': 'str'
    }

    attribute_map = {
        'capabilities': 'capabilities',
        'capability_grants': 'capabilityGrants',
        'created_at': 'createdAt',
        'data_id': 'dataId',
        'datasource_class': 'datasourceClass',
        'datasource_id': 'datasourceId',
        'datasource_name': 'datasourceName',
        'description': 'description',
        'effective_permissions': 'effectivePermissions',
        'id': 'id',
        'is_archived': 'isArchived',
        'is_enabled': 'isEnabled',
        'is_redacted': 'isRedacted',
        'is_remote_group_editable': 'isRemoteGroupEditable',
        'is_used_in_access_control_entries': 'isUsedInAccessControlEntries',
        'members': 'members',
        'name': 'name',
        'status_message': 'statusMessage',
        'sync_token': 'syncToken',
        'translation_key': 'translationKey',
        'type': 'type'
    }

    def __init__(self, capabilities=None, capability_grants=None, created_at=None, data_id=None, datasource_class=None, datasource_id=None, datasource_name=None, description=None, effective_permissions=None, id=None, is_archived=False, is_enabled=False, is_redacted=False, is_remote_group_editable=False, is_used_in_access_control_entries=False, members=None, name=None, status_message=None, sync_token=None, translation_key=None, type=None):
        """
        UserGroupOutputV1 - a model defined in Swagger
        """

        self._capabilities = None
        self._capability_grants = None
        self._created_at = None
        self._data_id = None
        self._datasource_class = None
        self._datasource_id = None
        self._datasource_name = None
        self._description = None
        self._effective_permissions = None
        self._id = None
        self._is_archived = None
        self._is_enabled = None
        self._is_redacted = None
        self._is_remote_group_editable = None
        self._is_used_in_access_control_entries = None
        self._members = None
        self._name = None
        self._status_message = None
        self._sync_token = None
        self._translation_key = None
        self._type = None

        if capabilities is not None:
          self.capabilities = capabilities
        if capability_grants is not None:
          self.capability_grants = capability_grants
        if created_at is not None:
          self.created_at = created_at
        if data_id is not None:
          self.data_id = data_id
        if datasource_class is not None:
          self.datasource_class = datasource_class
        if datasource_id is not None:
          self.datasource_id = datasource_id
        if datasource_name is not None:
          self.datasource_name = datasource_name
        if description is not None:
          self.description = description
        if effective_permissions is not None:
          self.effective_permissions = effective_permissions
        if id is not None:
          self.id = id
        if is_archived is not None:
          self.is_archived = is_archived
        if is_enabled is not None:
          self.is_enabled = is_enabled
        if is_redacted is not None:
          self.is_redacted = is_redacted
        if is_remote_group_editable is not None:
          self.is_remote_group_editable = is_remote_group_editable
        if is_used_in_access_control_entries is not None:
          self.is_used_in_access_control_entries = is_used_in_access_control_entries
        if members is not None:
          self.members = members
        if name is not None:
          self.name = name
        if status_message is not None:
          self.status_message = status_message
        if sync_token is not None:
          self.sync_token = sync_token
        if translation_key is not None:
          self.translation_key = translation_key
        if type is not None:
          self.type = type

    @property
    def capabilities(self):
        """
        Gets the capabilities of this UserGroupOutputV1.
        (DEPRECATED) Capabilities that the group has been granted

        :return: The capabilities of this UserGroupOutputV1.
        :rtype: list[CapabilityInheritanceOutputV1]
        """
        return self._capabilities

    @capabilities.setter
    def capabilities(self, capabilities):
        """
        Sets the capabilities of this UserGroupOutputV1.
        (DEPRECATED) Capabilities that the group has been granted

        :param capabilities: The capabilities of this UserGroupOutputV1.
        :type: list[CapabilityInheritanceOutputV1]
        """

        self._capabilities = capabilities

    @property
    def capability_grants(self):
        """
        Gets the capability_grants of this UserGroupOutputV1.
        Capabilities that the group has been granted, including where the capability was inherited from (if applicable)

        :return: The capability_grants of this UserGroupOutputV1.
        :rtype: list[CapabilityInheritanceOutputV1]
        """
        return self._capability_grants

    @capability_grants.setter
    def capability_grants(self, capability_grants):
        """
        Sets the capability_grants of this UserGroupOutputV1.
        Capabilities that the group has been granted, including where the capability was inherited from (if applicable)

        :param capability_grants: The capability_grants of this UserGroupOutputV1.
        :type: list[CapabilityInheritanceOutputV1]
        """

        self._capability_grants = capability_grants

    @property
    def created_at(self):
        """
        Gets the created_at of this UserGroupOutputV1.
        The ISO 8601 date of when the user was created (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :return: The created_at of this UserGroupOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this UserGroupOutputV1.
        The ISO 8601 date of when the user was created (YYYY-MM-DDThh:mm:ss.sssssssss±hh:mm)

        :param created_at: The created_at of this UserGroupOutputV1.
        :type: str
        """

        self._created_at = created_at

    @property
    def data_id(self):
        """
        Gets the data_id of this UserGroupOutputV1.
        The data ID of this item. Note: This is not the Seeq ID, but the unique identifier that the remote datasource uses.

        :return: The data_id of this UserGroupOutputV1.
        :rtype: str
        """
        return self._data_id

    @data_id.setter
    def data_id(self, data_id):
        """
        Sets the data_id of this UserGroupOutputV1.
        The data ID of this item. Note: This is not the Seeq ID, but the unique identifier that the remote datasource uses.

        :param data_id: The data_id of this UserGroupOutputV1.
        :type: str
        """

        self._data_id = data_id

    @property
    def datasource_class(self):
        """
        Gets the datasource_class of this UserGroupOutputV1.
        The datasource class, which is the type of system holding the item, such as OSIsoft PI

        :return: The datasource_class of this UserGroupOutputV1.
        :rtype: str
        """
        return self._datasource_class

    @datasource_class.setter
    def datasource_class(self, datasource_class):
        """
        Sets the datasource_class of this UserGroupOutputV1.
        The datasource class, which is the type of system holding the item, such as OSIsoft PI

        :param datasource_class: The datasource_class of this UserGroupOutputV1.
        :type: str
        """

        self._datasource_class = datasource_class

    @property
    def datasource_id(self):
        """
        Gets the datasource_id of this UserGroupOutputV1.
        The datasource identifier, which is how the datasource holding this item identifies itself

        :return: The datasource_id of this UserGroupOutputV1.
        :rtype: str
        """
        return self._datasource_id

    @datasource_id.setter
    def datasource_id(self, datasource_id):
        """
        Sets the datasource_id of this UserGroupOutputV1.
        The datasource identifier, which is how the datasource holding this item identifies itself

        :param datasource_id: The datasource_id of this UserGroupOutputV1.
        :type: str
        """

        self._datasource_id = datasource_id

    @property
    def datasource_name(self):
        """
        Gets the datasource_name of this UserGroupOutputV1.
        The name of the data source (authentication directory) containing the group

        :return: The datasource_name of this UserGroupOutputV1.
        :rtype: str
        """
        return self._datasource_name

    @datasource_name.setter
    def datasource_name(self, datasource_name):
        """
        Sets the datasource_name of this UserGroupOutputV1.
        The name of the data source (authentication directory) containing the group

        :param datasource_name: The datasource_name of this UserGroupOutputV1.
        :type: str
        """

        self._datasource_name = datasource_name

    @property
    def description(self):
        """
        Gets the description of this UserGroupOutputV1.
        Clarifying information or other plain language description of this item

        :return: The description of this UserGroupOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UserGroupOutputV1.
        Clarifying information or other plain language description of this item

        :param description: The description of this UserGroupOutputV1.
        :type: str
        """

        self._description = description

    @property
    def effective_permissions(self):
        """
        Gets the effective_permissions of this UserGroupOutputV1.

        :return: The effective_permissions of this UserGroupOutputV1.
        :rtype: PermissionsV1
        """
        return self._effective_permissions

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions):
        """
        Sets the effective_permissions of this UserGroupOutputV1.

        :param effective_permissions: The effective_permissions of this UserGroupOutputV1.
        :type: PermissionsV1
        """

        self._effective_permissions = effective_permissions

    @property
    def id(self):
        """
        Gets the id of this UserGroupOutputV1.
        The ID that can be used to interact with the item

        :return: The id of this UserGroupOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this UserGroupOutputV1.
        The ID that can be used to interact with the item

        :param id: The id of this UserGroupOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def is_archived(self):
        """
        Gets the is_archived of this UserGroupOutputV1.
        Whether item is archived

        :return: The is_archived of this UserGroupOutputV1.
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """
        Sets the is_archived of this UserGroupOutputV1.
        Whether item is archived

        :param is_archived: The is_archived of this UserGroupOutputV1.
        :type: bool
        """

        self._is_archived = is_archived

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this UserGroupOutputV1.
        Whether the group is enabled

        :return: The is_enabled of this UserGroupOutputV1.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this UserGroupOutputV1.
        Whether the group is enabled

        :param is_enabled: The is_enabled of this UserGroupOutputV1.
        :type: bool
        """

        self._is_enabled = is_enabled

    @property
    def is_redacted(self):
        """
        Gets the is_redacted of this UserGroupOutputV1.
        Whether item is redacted

        :return: The is_redacted of this UserGroupOutputV1.
        :rtype: bool
        """
        return self._is_redacted

    @is_redacted.setter
    def is_redacted(self, is_redacted):
        """
        Sets the is_redacted of this UserGroupOutputV1.
        Whether item is redacted

        :param is_redacted: The is_redacted of this UserGroupOutputV1.
        :type: bool
        """

        self._is_redacted = is_redacted

    @property
    def is_remote_group_editable(self):
        """
        Gets the is_remote_group_editable of this UserGroupOutputV1.
        Whether the user group remains editable in Seeq even when sourced from a remote system.

        :return: The is_remote_group_editable of this UserGroupOutputV1.
        :rtype: bool
        """
        return self._is_remote_group_editable

    @is_remote_group_editable.setter
    def is_remote_group_editable(self, is_remote_group_editable):
        """
        Sets the is_remote_group_editable of this UserGroupOutputV1.
        Whether the user group remains editable in Seeq even when sourced from a remote system.

        :param is_remote_group_editable: The is_remote_group_editable of this UserGroupOutputV1.
        :type: bool
        """

        self._is_remote_group_editable = is_remote_group_editable

    @property
    def is_used_in_access_control_entries(self):
        """
        Gets the is_used_in_access_control_entries of this UserGroupOutputV1.
        Whether the group is used in any access control entries

        :return: The is_used_in_access_control_entries of this UserGroupOutputV1.
        :rtype: bool
        """
        return self._is_used_in_access_control_entries

    @is_used_in_access_control_entries.setter
    def is_used_in_access_control_entries(self, is_used_in_access_control_entries):
        """
        Sets the is_used_in_access_control_entries of this UserGroupOutputV1.
        Whether the group is used in any access control entries

        :param is_used_in_access_control_entries: The is_used_in_access_control_entries of this UserGroupOutputV1.
        :type: bool
        """

        self._is_used_in_access_control_entries = is_used_in_access_control_entries

    @property
    def members(self):
        """
        Gets the members of this UserGroupOutputV1.
        The members of the group

        :return: The members of this UserGroupOutputV1.
        :rtype: list[IdentityPreviewV1]
        """
        return self._members

    @members.setter
    def members(self, members):
        """
        Sets the members of this UserGroupOutputV1.
        The members of the group

        :param members: The members of this UserGroupOutputV1.
        :type: list[IdentityPreviewV1]
        """

        self._members = members

    @property
    def name(self):
        """
        Gets the name of this UserGroupOutputV1.
        The human readable name

        :return: The name of this UserGroupOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UserGroupOutputV1.
        The human readable name

        :param name: The name of this UserGroupOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def status_message(self):
        """
        Gets the status_message of this UserGroupOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :return: The status_message of this UserGroupOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this UserGroupOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :param status_message: The status_message of this UserGroupOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def sync_token(self):
        """
        Gets the sync_token of this UserGroupOutputV1.
        An arbitrary token (often a date or random ID) that is used during metadata syncs. At the end of a full sync, items with mismatching sync tokens are identified as stale and may be  archived using the Datasources clean-up API.

        :return: The sync_token of this UserGroupOutputV1.
        :rtype: str
        """
        return self._sync_token

    @sync_token.setter
    def sync_token(self, sync_token):
        """
        Sets the sync_token of this UserGroupOutputV1.
        An arbitrary token (often a date or random ID) that is used during metadata syncs. At the end of a full sync, items with mismatching sync tokens are identified as stale and may be  archived using the Datasources clean-up API.

        :param sync_token: The sync_token of this UserGroupOutputV1.
        :type: str
        """

        self._sync_token = sync_token

    @property
    def translation_key(self):
        """
        Gets the translation_key of this UserGroupOutputV1.
        The item's translation key, if any

        :return: The translation_key of this UserGroupOutputV1.
        :rtype: str
        """
        return self._translation_key

    @translation_key.setter
    def translation_key(self, translation_key):
        """
        Sets the translation_key of this UserGroupOutputV1.
        The item's translation key, if any

        :param translation_key: The translation_key of this UserGroupOutputV1.
        :type: str
        """

        self._translation_key = translation_key

    @property
    def type(self):
        """
        Gets the type of this UserGroupOutputV1.
        The type of the item

        :return: The type of this UserGroupOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this UserGroupOutputV1.
        The type of the item

        :param type: The type of this UserGroupOutputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, UserGroupOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
